==> cms-db_v0.7.9.tar.gz: admin/editpage.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
include('../functions_url.inc.php');

if (isset($_POST['button'])) {
	//START
	$shorturl = get_filename_from_url($_POST['file']);
	if ($shorturl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$filename = '../data/pages'.$shorturl;
	$content = $_POST['content'];
	$content = stripslashes($content);
	include('mobile.inc.php');
	if (mobile()) {
		include('mobilemarkup.inc.php');
		$content = get_xhtml_from_mm($content);
	}
	if (is_writable($filename)) {
		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'editpage.php?file='.$filename.'&'.SID);
		}
		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'editpage.php?file='.$filename.'&'.SID);
		}
		fclose($handle);
		if (file_exists('../data/.autosave_'.$_POST['file'])) {
			unlink('../data/.autosave_'.$_POST['file']);
		}
		if ($_POST['redirect'] == '1' || preg_match('/%%REDIRECT-(.*)%%/U', $content)) {
			include('cache.inc.php');
			clear_cache('pages');
		} else {
			$dir = substr($shorturl, 0, strrpos($shorturl, '/'));
			$dir = '../data/pages'.substr($dir, 0, strrpos($dir, '/'));
			$contents = file_get_contents($dir.'/01,Home');
			if (strpos($contents, '%%SECTIONLIST%%') !== false) {
				include('cache.inc.php');
				clear_cache('pages');
			}
		}
		include('urlindex.inc.php');
		generate_urlindex();
		header('Location:pages.php?saved='.urlencode($filename).'&'.SID.'#edit');
	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'editpage.php?file='.$filename.'&'.SID);
	}
	//ENDE
} else {
	include('../data/settings/url.inc.php');
	$shorturl = $_GET['file'];
	$longurl = get_filename_from_url($shorturl);
	if ($longurl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$filename = '../data/pages'.$longurl;
	$pagetitle = basename(dirname($filename));
	$pagetitle = substr($pagetitle, 3);
	$pagetitle = str_replace('_', ' ', $pagetitle);
	$pagetitle = str_replace('"SLASH', '/', $pagetitle);
	$pagetitle = str_replace('AND', '&', $pagetitle);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><?php locale('title_editpage') ?></title>
	<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
	<link rel="stylesheet" type="text/css" href="style.css" />
	<?php
	include('wymeditor.inc.php');
	?>
	<script type="text/javascript">
	<!--
	var defaultautosafeinterval = 30; // defines the interval for doing an autosave in seconds

	function saved(ret) {
		$("#autosave").text('<?php locale('desc_autosave-saved') ?>');
		autosavecount = defaultautosafeinterval;
		autosaveinterval = window.setInterval("autosave()", 1000);
	}
	function save() {
		window.clearInterval(autosaveinterval);
		var content = getTextareaContent('#content');
		if (oldcontent != content) {
			oldcontent = content;
			$("#autosave").text('<?php locale('desc_autosave-saving') ?>');
			var request = initAjax();
			doPOSTRequest(request, 'saved', 'autosave.php?<?php echo SID ?>', 'file=<?php echo $shorturl ?>&content='+encodeURIComponent(content));
		} else {
			$("#autosave").text('<?php locale('desc_autosave-skipped') ?>');
			autosavecount = defaultautosafeinterval;
			autosaveinterval = window.setInterval("autosave()", 1000);
		}
	}
	function autosave() {
		autosavecount = autosavecount - 1;
		$("#autosave").text('<?php printf(locale('desc_autosave-next',true), '\'+autosavecount+\'') ?>');
		if (autosavecount == 0) {
			save();
		}
	}
	$(window).load(function () {
		$("#save").html('<input type="button" id="autosavebutton" name="button" value="<?php locale('button_save') ?>" disabled="disabled" />').find("input").click(save);
		// Timeout as work-arounf for Opera: wait for WYMeditor to load
		waitint = window.setInterval(function () { $("#autosave").append('.'); }, 1000);
		window.setTimeout(function () {
			oldcontent = getTextareaContent('#content');
			autosavecount = defaultautosafeinterval;
			autosaveinterval = window.setInterval("autosave()", 1000);
			$("#autosavebutton").removeAttr("disabled");
			window.clearInterval(waitint);
		}, 5000);
	});
	//-->
	</script>
</head>
<body>

	<h1><?php locale('title_editpage') ?>: <?php echo htmlspecialchars($pagetitle) ?></h1>
	<noscript><p class="hint"><?php locale('desc_javascript') ?></p></noscript>
	<?php
	if (file_exists('../data/.autosave_'.$shorturl)) {
		if (!isset($_GET['discard'])) {
			echo '<p class="hint">'.locale('desc_autosave-version',true).' <a href="editpage.php?file='.$shorturl.'&discard=true&'.SID.'" class="nonewtab">'.locale('link_discard-changes',true).'</a></p>';
			$filename = '../data/.autosave_'.$shorturl;
		} else {
			unlink('../data/.autosave_'.$shorturl);
		}
	}
	?>
	<p>
		<form action="editpage.php?<?php echo SID ?>" method="post">
			<input type="hidden" name="file" value="<?php echo $shorturl ?>" />
			<!--style"border: 1px solid #BFBFBF; font-family: Verdana; font-size: 12px;"-->
			<?php
			include('getcontent.inc.php');
			if (mobile()) {
				include('mobilemarkup.inc.php');
				$content = GetContent($filename, false);
				$content = get_mm_from_xhtml($content);
			} else {
				$content = GetContent($filename);
			}
			if (preg_match('/%%REDIRECT-(.*)%%/U', $content)) {
				echo '<input type="hidden" name="redirect" value="1" />';
			} else {
				echo '<input type="hidden" name="redirect" value="0" />';
			}
			?>
			<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php echo $content ?></textarea><br />
			<div id="formbuttons">
				<input type="submit" name="button" value="<?php locale('button_publish') ?>" class="wymupdate" />
				<span id="save">&nbsp;</span>
				<span id="autosave" style="color: #555">&nbsp;</span>
			</div>
		</form>
	</p>
	<p>
		<?php locale('desc_variables') ?>
		<a href="variables.php?<?php echo SID ?>"><?php locale('link_variables') ?></a>
	</p>

</body>
</html>
<?php
}
?>

==> cms-db_v0.7.11.tar.gz: admin/editpage.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
include('../functions_url.inc.php');

if (isset($_POST['button'])) {
	//START
	$shorturl = get_filename_from_url($_POST['file']);
	if ($shorturl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$filename = '../data/pages'.$shorturl;
	$content = $_POST['content'];
	$content = stripslashes($content);
	include('mobile.inc.php');
	if (mobile()) {
		include('mobilemarkup.inc.php');
		$content = get_xhtml_from_mm($content);
	}
	if (is_writable($filename)) {
		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file', true), $filename), 'editpage.php?file='.$filename.'&'.SID);
		}
		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file', true), $filename), 'editpage.php?file='.$filename.'&'.SID);
		}
		fclose($handle);
		if (file_exists('../data/.autosave_'.$_POST['file'])) {
			unlink('../data/.autosave_'.$_POST['file']);
		}
		if ($_POST['redirect'] == '1' || preg_match('/%%REDIRECT-(.*)%%/U', $content)) {
			include('cache.inc.php');
			clear_cache('pages');
		} else {
			$dir = substr($shorturl, 0, strrpos($shorturl, '/'));
			$dir = '../data/pages'.substr($dir, 0, strrpos($dir, '/'));
			$contents = file_get_contents($dir.'/01,Home');
			if (strpos($contents, '%%SECTIONLIST%%') !== false) {
				include('cache.inc.php');
				clear_cache('pages');
			}
		}
		include('urlindex.inc.php');
		generate_urlindex();
		header('Location:pages.php?saved='.urlencode($filename).'&'.SID.'#edit');
	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms', true), $filename), 'editpage.php?file='.$filename.'&'.SID);
	}
	//ENDE
} else {
	include('../data/settings/url.inc.php');
	$shorturl = $_GET['file'];
	$longurl = get_filename_from_url($shorturl);
	if ($longurl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$filename = '../data/pages'.$longurl;
	$pagetitle = basename(dirname($filename));
	$pagetitle = substr($pagetitle, 3);
	$pagetitle = str_replace('_', ' ', $pagetitle);
	$pagetitle = str_replace('"SLASH', '/', $pagetitle);
	$pagetitle = str_replace('AND', '&', $pagetitle);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><?php locale('title_editpage') ?></title>
	<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
	<link rel="stylesheet" type="text/css" href="style.css" />
	<?php
	include('wymeditor.inc.php');
	?>
	<script type="text/javascript">
	<!--
	var defaultautosafeinterval = 30; // defines the interval for doing an autosave in seconds

	function saved(ret) {
		$("#autosave").text('<?php locale_escape('desc_autosave-saved', "'") ?>');
		autosavecount = defaultautosafeinterval;
		autosaveinterval = window.setInterval("autosave()", 1000);
	}
	function save() {
		window.clearInterval(autosaveinterval);
		var content = getTextareaContent('#content');
		if (oldcontent != content) {
			oldcontent = content;
			$("#autosave").text('<?php locale_escape('desc_autosave-saving', "'") ?>');
			var request = initAjax();
			doPOSTRequest(request, 'saved', 'autosave.php?<?php echo SID ?>', 'file=<?php echo $shorturl ?>&content='+encodeURIComponent(content));
		} else {
			$("#autosave").text('<?php locale_escape('desc_autosave-skipped', "'") ?>');
			autosavecount = defaultautosafeinterval;
			autosaveinterval = window.setInterval("autosave()", 1000);
		}
	}
	function autosave() {
		autosavecount = autosavecount - 1;
		$("#autosave").text('<?php printf(locale_escape('desc_autosave-next', "'", true), '\'+autosavecount+\'') ?>');
		if (autosavecount == 0) {
			save();
		}
	}
	$(window).load(function () {
		$("#save").html('<input type="button" id="autosavebutton" name="button" value="<?php locale_escape('button_savedraft', "'") ?>" disabled="disabled" />').find("input").click(save);
		// Timeout as work-arounf for Opera: wait for WYMeditor to load
		waitint = window.setInterval(function () { $("#autosave").append('.'); }, 1000);
		window.setTimeout(function () {
			oldcontent = getTextareaContent('#content');
			autosavecount = defaultautosafeinterval;
			autosaveinterval = window.setInterval("autosave()", 1000);
			$("#autosavebutton").removeAttr("disabled");
			window.clearInterval(waitint);
		}, 5000);
	});
	//-->
	</script>
</head>
<body>

	<h1><?php locale('title_editpage') ?>: <?php echo htmlspecialchars($pagetitle) ?></h1>
	<noscript><p class="hint"><?php locale('desc_javascript') ?></p></noscript>
	<?php
	if (file_exists('../data/.autosave_'.$shorturl)) {
		if (!isset($_GET['discard'])) {
			echo '<p class="hint">'.locale('desc_autosave-version',true).' <a href="editpage.php?file='.$shorturl.'&discard=true&'.SID.'" class="nonewtab">'.locale('link_discard-changes',true).'</a></p>';
			$filename = '../data/.autosave_'.$shorturl;
		} else {
			unlink('../data/.autosave_'.$shorturl);
		}
	}
	?>
	<p>
		<form action="editpage.php?<?php echo SID ?>" method="post">
			<input type="hidden" name="file" value="<?php echo $shorturl ?>" />
			<!--style"border: 1px solid #BFBFBF; font-family: Verdana; font-size: 12px;"-->
			<?php
			include('getcontent.inc.php');
			if (mobile()) {
				include('mobilemarkup.inc.php');
				$content = GetContent($filename, false);
				$content = get_mm_from_xhtml($content);
			} else {
				$content = GetContent($filename);
			}
			if (preg_match('/%%REDIRECT-(.*)%%/U', $content)) {
				echo '<input type="hidden" name="redirect" value="1" />';
			} else {
				echo '<input type="hidden" name="redirect" value="0" />';
			}
			?>
			<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php echo $content ?></textarea><br />
			<div id="formbuttons">
				<input type="submit" name="button" value="<?php locale('button_publish') ?>" class="wymupdate" />
				<span id="save">&nbsp;</span>
				<span id="autosave" style="color: #555">&nbsp;</span>
			</div>
		</form>
	</p>
	<p>
		<?php locale('desc_variables') ?>
		<a href="variables.php?<?php echo SID ?>"><?php locale('link_variables') ?></a>
	</p>

</body>
</html>
<?php
}
?>
